summaryrefslogtreecommitdiffstats
path: root/bridges/source/cpp_uno/gcc3_linux_ia64/cpp2uno.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'bridges/source/cpp_uno/gcc3_linux_ia64/cpp2uno.cxx')
-rw-r--r--bridges/source/cpp_uno/gcc3_linux_ia64/cpp2uno.cxx43
1 files changed, 22 insertions, 21 deletions
diff --git a/bridges/source/cpp_uno/gcc3_linux_ia64/cpp2uno.cxx b/bridges/source/cpp_uno/gcc3_linux_ia64/cpp2uno.cxx
index fe880b2aa449..e897397ce76b 100644
--- a/bridges/source/cpp_uno/gcc3_linux_ia64/cpp2uno.cxx
+++ b/bridges/source/cpp_uno/gcc3_linux_ia64/cpp2uno.cxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -55,7 +56,7 @@ static typelib_TypeClass cpp2uno_call(
void ** gpreg, void ** fpreg, void ** ovrflw,
sal_Int64 * pRegisterReturn /* space for register return */ )
{
-#ifdef CMC_DEBUG
+#if OSL_DEBUG_LEVEL > 2
fprintf(stderr, "as far as cpp2uno_call\n");
#endif
@@ -120,14 +121,14 @@ static typelib_TypeClass cpp2uno_call(
typelib_TypeDescription * pParamTypeDescr = 0;
TYPELIB_DANGER_GET( &pParamTypeDescr, rParam.pTypeRef );
-#ifdef CMC_DEBUG
+#if OSL_DEBUG_LEVEL > 2
fprintf(stderr, "arg %d of %d\n", nPos, nParams);
#endif
//I think it is impossible to get UNO to pass structs as parameters by copy
if (!rParam.bOut && bridges::cpp_uno::shared::isSimpleType( pParamTypeDescr ))
{
-#ifdef CMC_DEBUG
+#if OSL_DEBUG_LEVEL > 2
fprintf(stderr, "simple\n");
#endif
@@ -193,7 +194,7 @@ static typelib_TypeClass cpp2uno_call(
}
else // ptr to complex value | ref
{
-#ifdef CMC_DEBUG
+#if OSL_DEBUG_LEVEL > 2
fprintf(stderr, "complex, ng is %d\n", ng);
#endif
void *pCppStack; //temporary stack pointer
@@ -237,7 +238,7 @@ static typelib_TypeClass cpp2uno_call(
}
}
-#ifdef CMC_DEBUG
+#if OSL_DEBUG_LEVEL > 2
fprintf(stderr, "end of params\n");
#endif
@@ -248,7 +249,7 @@ static typelib_TypeClass cpp2uno_call(
// invoke uno dispatch call
(*pThis->getUnoI()->pDispatcher)( pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
// in case an exception occured...
if (pUnoExc)
{
// destruct temporary in/inout params
@@ -268,7 +269,7 @@ static typelib_TypeClass cpp2uno_call(
// is here for dummy
return typelib_TypeClass_VOID;
}
- else // else no exception occured...
+ else // else no exception occurred...
{
// temporary params
for ( ; nTempIndizes--; )
@@ -335,25 +336,25 @@ static typelib_TypeClass cpp_mediate(
{
nFunctionIndex &= 0x7fffffff;
pThis = gpreg[1];
-#ifdef CMC_DEBUG
+#if OSL_DEBUG_LEVEL > 2
fprintf(stderr, "pThis is gpreg[1]\n");
#endif
}
else
{
pThis = gpreg[0];
-#ifdef CMC_DEBUG
+#if OSL_DEBUG_LEVEL > 2
fprintf(stderr, "pThis is gpreg[0]\n");
#endif
}
-#ifdef CMC_DEBUG
+#if OSL_DEBUG_LEVEL > 2
fprintf(stderr, "pThis is %p\n", pThis);
#endif
pThis = static_cast< char * >(pThis) - nVtableOffset;
-#ifdef CMC_DEBUG
+#if OSL_DEBUG_LEVEL > 2
fprintf(stderr, "pThis is now %p\n", pThis);
#endif
@@ -363,7 +364,7 @@ static typelib_TypeClass cpp_mediate(
typelib_InterfaceTypeDescription * pTypeDescr = pCppI->getTypeDescr();
-#ifdef CMC_DEBUG
+#if OSL_DEBUG_LEVEL > 2
fprintf(stderr, "indexes are %d %d\n", nFunctionIndex, pTypeDescr->nMapFunctionIndexToMemberIndex);
#endif
@@ -371,7 +372,7 @@ static typelib_TypeClass cpp_mediate(
if (nFunctionIndex >= pTypeDescr->nMapFunctionIndexToMemberIndex)
{
throw RuntimeException(
- rtl::OUString::createFromAscii("illegal vtable index!"),
+ rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "illegal vtable index!" )),
(XInterface *)pThis );
}
@@ -379,7 +380,7 @@ static typelib_TypeClass cpp_mediate(
sal_Int32 nMemberPos = pTypeDescr->pMapFunctionIndexToMemberIndex[nFunctionIndex];
OSL_ENSURE( nMemberPos < pTypeDescr->nAllMembers, "### illegal member index!" );
-#ifdef CMC_DEBUG
+#if OSL_DEBUG_LEVEL > 2
fprintf(stderr, "members are %d %d\n", nMemberPos, pTypeDescr->nAllMembers);
#endif
@@ -467,19 +468,19 @@ static typelib_TypeClass cpp_mediate(
}
default:
{
-#ifdef CMC_DEBUG
+#if OSL_DEBUG_LEVEL > 2
fprintf(stderr, "screwed\n");
#endif
throw RuntimeException(
- rtl::OUString::createFromAscii("no member description found!"),
+ rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "no member description found!" )),
(XInterface *)pThis );
// is here for dummy
eRet = typelib_TypeClass_VOID;
}
}
-#ifdef CMC_DEBUG
+#if OSL_DEBUG_LEVEL > 2
fprintf(stderr, "end of cpp_mediate\n");
#endif
return eRet;
@@ -519,7 +520,7 @@ extern "C" ia64::RegReturn cpp_vtable_call(
register double f14 asm("f14"); fpreg[6] = f14;
register double f15 asm("f15"); fpreg[7] = f15;
-#ifdef CMC_DEBUG
+#if OSL_DEBUG_LEVEL > 2
fprintf(stderr, "cpp_vtable_call called with %lx\n", nOffsetAndIndex);
fprintf(stderr, "adump is %lx %lx %lx %lx %lx %lx %lx %lx\n", in0, in1, in2, in3, in4, in5, in6, in7);
fprintf(stderr, "bdump is %f %f %f %f %f %f %f %f\n", f8, f9, f10, f11, f12, f13, f14, f15);
@@ -575,7 +576,7 @@ const int codeSnippetSize = 40;
bridges::cpp_uno::shared::VtableFactory::Slot codeSnippet( unsigned char * code, sal_PtrDiff writetoexecdiff, sal_Int32 nFunctionIndex, sal_Int32 nVtableOffset,
bool bHasHiddenParam )
{
-#ifdef CMC_DEBUG
+#if OSL_DEBUG_LEVEL > 2
fprintf(stderr, "size is %d\n", codeSnippetSize);
fprintf(stderr,"in codeSnippet functionIndex is %x\n", nFunctionIndex);
fprintf(stderr,"in codeSnippet vtableOffset is %x\n", nVtableOffset);
@@ -631,7 +632,7 @@ unsigned char * bridges::cpp_uno::shared::VtableFactory::addLocalFunctions(
{
(*in_slots) -= functionCount;
Slot * slots = *in_slots;
-#ifdef CMC_DEBUG
+#if OSL_DEBUG_LEVEL > 2
fprintf(stderr, "in addLocalFunctions functionOffset is %x\n",functionOffset);
fprintf(stderr, "in addLocalFunctions vtableOffset is %x\n",vtableOffset);
#endif
@@ -681,4 +682,4 @@ unsigned char * bridges::cpp_uno::shared::VtableFactory::addLocalFunctions(
return code;
}
-/* vi:set tabstop=4 shiftwidth=4 expandtab: */
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
@@ -248,7 +249,7 @@ static typelib_TypeClass cpp2uno_call(
// invoke uno dispatch call
(*pThis->getUnoI()->pDispatcher)( pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
- // in case an exception occured...
+ // in case an exception occurred...
if (pUnoExc)
{